@@ -1,7 +1,6 @@
 import logging
-from pprint import pprint
 
-import requests
+from aiohttp import ClientSession
 
 from skyhub.loggin_config import *
 from skyhub.models.produto import Produto
@@ -11,21 +10,26 @@ logger.addHandler(f_handler)
 
 
 class BlingController:
-    def __init__(self, credentials: dict, base_url: str, request: requests) -> None:
+    def __init__(
+        self, credentials: dict, base_url: str, request: ClientSession
+    ) -> None:
         self.credentials = credentials
         self.base_url = base_url
         self.request = request
 
-    def get_produto(self, sku: str) -> Produto:
+    async def get_produto(self, sku: str) -> Produto:
         url = f"{self.base_url}/{sku}/json?estoque=S"
-        response = self.request.get(url, params=self.credentials)
-        retorno = response.json().get("retorno")
+        response = await self.request.request(
+            method="GET", url=url, params=self.credentials
+        )
+        response_json = await response.json()
+        retorno = response_json.get("retorno")
 
         if "erros" in retorno:
             logger.warning(f"O produto {sku} não foi encontrado!")
             return False
 
-        if response.status_code == 200:
+        if response.status == 200:
             produtos = retorno.get("produtos")
             produtoJson = produtos[0].get("produto")
 
@@ -35,26 +39,19 @@ class BlingController:
 
             return Produto(codigo, preco, estoque_atual)
 
-    def atualiza_produto(self, produto: Produto) -> bool:
-        XML = f"""
-<produto>
-    <codigo>{produto.sku}</codigo>
-    <vlr_unit>{produto.price}</vlr_unit>
-    <estoque>{produto.qty}</estoque>
-</produto>
-        """
+    async def atualiza_produto(self, produto: Produto) -> bool:
+        xml = produto.toXML()
         apikey = self.credentials.get("apikey", "")
+        data = {"apikey": apikey, "xml": xml}
 
         url = f"{self.base_url}/{produto.sku}/json?estoque=S"
-        data = {"apikey": apikey, "xml": XML}
-        response = self.request.post(url, data=data)
+        response = await self.request.request(method="POST", url=url, data=data)
 
-        print(response.status_code)
-        if response.status_code == 201:
+        if response.status == 201:
             logger.info(f"O produto '{produto.sku}' foi atualizado.")
             return True
 
         else:
-            print(response.status_code)
+            print(response.status)
             logger.warning(f"O produto '{produto.sku}' não pode ser atualizado.")
             return False
